ai:::ignore
title:::

set:::object_name jacket-design-v3

ai:::object get:::object_name
ai:::ignore

Objective: To build a smart winter jacket with a lithium battery and 320 cm of heating wire.

ai:::complete watts Imagine an adult person who is wearing a normal jacket in a -10-celsius  winter. To make them feel warm, how many watts of energy should we add, so to speak, inside the jacket? This is the heat that is generated by this device.

ai:::complete current What is the nominal current that is drawn from the battery?

ai:::complete resistance What is the resistance per meter of the heating wire?

ai:::complete operation-time If we use a battery-capacity::: li-ion battery, for how long can we keep this device on?

## build

```bash
@sbc build_README \
	ai,root=shelter/jacket/design

@upload public,zip get:::object_name
```

object:::get:::object_name